"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGlibcVersion = exports.buildInfo = exports.baseBuildInfo = void 0;
const os_1 = __importDefault(require("os"));
const service_provider_node_driver_1 = require("@mongosh/service-provider-node-driver");
function getSystemArch() {
    return process.platform === 'darwin'
        ? os_1.default.cpus().some((cpu) => {
            return /Apple/.test(cpu.model);
        })
            ? 'arm64'
            : 'x64'
        : process.arch;
}
function baseBuildInfo() {
    var _a;
    const runtimeData = {
        nodeVersion: process.version,
        opensslVersion: process.versions.openssl,
        sharedOpenssl: !!process.config.variables.node_shared_openssl,
        runtimeArch: getSystemArch(),
        runtimePlatform: process.platform,
        runtimeGlibcVersion: (_a = getGlibcVersion()) !== null && _a !== void 0 ? _a : 'N/A',
    };
    try {
        return {
            ...require('./build-info.json'),
            ...runtimeData,
        };
    }
    catch (_b) {
        const { version } = require('../package.json');
        return {
            version,
            distributionKind: 'unpackaged',
            buildArch: process.arch,
            buildPlatform: process.platform,
            buildTarget: 'unknown',
            buildTime: null,
            gitVersion: null,
            ...runtimeData,
        };
    }
}
exports.baseBuildInfo = baseBuildInfo;
async function buildInfo({ withSegmentApiKey, } = {}) {
    const dependencyVersionInfo = {
        ...service_provider_node_driver_1.NodeDriverServiceProvider.getVersionInformation(),
    };
    const buildInfo = { ...baseBuildInfo(), deps: { ...dependencyVersionInfo } };
    if (!withSegmentApiKey) {
        delete buildInfo.segmentApiKey;
    }
    return buildInfo;
}
exports.buildInfo = buildInfo;
let cachedGlibcVersion = null;
function getGlibcVersion() {
    if (process.platform !== 'linux')
        return undefined;
    if (cachedGlibcVersion !== null)
        return cachedGlibcVersion;
    try {
        return (cachedGlibcVersion = require('glibc-version')());
    }
    catch (_a) {
        return (cachedGlibcVersion = undefined);
    }
}
exports.getGlibcVersion = getGlibcVersion;
//# sourceMappingURL=build-info.js.map