import type { ConnectLogEmitter } from './index';
import type { MongoClient, MongoClientOptions } from 'mongodb';
import type { MongoDBOIDCPlugin, MongoDBOIDCPluginOptions } from '@mongodb-js/oidc-plugin';
import { DevtoolsProxyOptions, AgentWithInitialize } from '@mongodb-js/devtools-proxy-support';
export type { DevtoolsProxyOptions, AgentWithInitialize };
export declare class MongoAutoencryptionUnavailable extends Error {
    constructor();
}
export declare class DevtoolsConnectionState {
    oidcPlugin: MongoDBOIDCPlugin;
    productName: string;
    private stateShareClient;
    private stateShareServer;
    constructor(options: Pick<DevtoolsConnectOptions, 'productDocsLink' | 'productName' | 'oidc' | 'parentHandle'>, logger: ConnectLogEmitter, ca: string);
    getStateShareServer(): Promise<string>;
    destroy(): Promise<void>;
}
export interface DevtoolsConnectOptions extends MongoClientOptions {
    productDocsLink: string;
    productName: string;
    oidc?: Omit<MongoDBOIDCPluginOptions, 'logger' | 'redirectServerRequestHandler'>;
    parentState?: DevtoolsConnectionState;
    parentHandle?: string;
    proxy?: DevtoolsProxyOptions | AgentWithInitialize;
    applyProxyToOIDC?: boolean;
}
export declare function connectMongoClient(uri: string, clientOptions: DevtoolsConnectOptions, logger: ConnectLogEmitter, MongoClientClass: typeof MongoClient): Promise<{
    client: MongoClient;
    state: DevtoolsConnectionState;
}>;
export declare function isHumanOidcFlow(uri: string, clientOptions: MongoClientOptions): boolean;
//# sourceMappingURL=connect.d.ts.map