import type Collection from './collection';
import type Mongo from './mongo';
import ExplainableCursor from './explainable-cursor';
import { ShellApiWithMongoClass } from './decorators';
import { asPrintable } from './enums';
import type { RemoveShellOptions, FindAndModifyShellOptions, FindAndModifyMethodShellOptions, MapReduceShellOptions } from './helpers';
import type { Document, ExplainVerbosityLike, CountOptions, DistinctOptions, UpdateOptions, FindOneAndDeleteOptions, FindOneAndReplaceOptions, FindOneAndUpdateOptions, FindOptions } from '@mongosh/service-provider-core';
export default class Explainable extends ShellApiWithMongoClass {
    _mongo: Mongo;
    _collection: Collection;
    _verbosity: ExplainVerbosityLike;
    constructor(mongo: Mongo, collection: Collection, verbosity: ExplainVerbosityLike);
    [asPrintable](): string;
    private _emitExplainableApiCall;
    getCollection(): Collection;
    getVerbosity(): ExplainVerbosityLike;
    setVerbosity(verbosity: ExplainVerbosityLike): void;
    find(query?: Document, projection?: Document, options?: FindOptions): Promise<ExplainableCursor>;
    aggregate(pipeline: Document[], options: Document): Promise<Document>;
    aggregate(...stages: Document[]): Promise<Document>;
    count(query?: {}, options?: CountOptions): Promise<Document>;
    distinct(field: string): Promise<Document>;
    distinct(field: string, query: Document): Promise<Document>;
    distinct(field: string, query: Document, options: DistinctOptions): Promise<Document>;
    findAndModify(options: FindAndModifyMethodShellOptions): Promise<Document | null>;
    findOneAndDelete(filter: Document, options?: FindOneAndDeleteOptions): Promise<Document | null>;
    findOneAndReplace(filter: Document, replacement: Document, options?: FindAndModifyShellOptions<FindOneAndReplaceOptions>): Promise<Document>;
    findOneAndUpdate(filter: Document, update: Document, options?: FindAndModifyShellOptions<FindOneAndUpdateOptions>): Promise<Document>;
    remove(query: Document, options?: boolean | RemoveShellOptions): Promise<Document>;
    update(filter: Document, update: Document, options?: UpdateOptions): Promise<Document>;
    mapReduce(map: Function | string, reduce: Function | string, optionsOrOutString: MapReduceShellOptions): Promise<Document>;
}
