/// <reference types="node" />
import Help from './help';
import type { BinaryType, Document } from '@mongosh/service-provider-core';
import { bson as BSON } from '@mongosh/service-provider-core';
type LongWithoutAccidentallyExposedMethods = Omit<typeof BSON.Long, 'fromExtendedJSON'>;
interface ShellBsonBase {
    DBRef: (namespace: string, oid: any, db?: string, fields?: Document) => typeof BSON.DBRef.prototype;
    bsonsize: (object: any) => number;
    MaxKey: () => typeof BSON.MaxKey.prototype;
    MinKey: () => typeof BSON.MinKey.prototype;
    ObjectId: (id?: string | number | typeof BSON.ObjectId.prototype | Buffer) => typeof BSON.ObjectId.prototype;
    Timestamp: (t?: number | typeof BSON.Long.prototype | {
        t: number;
        i: number;
    }, i?: number) => typeof BSON.Timestamp.prototype;
    Code: (c?: string | Function, s?: any) => typeof BSON.Code.prototype;
    NumberDecimal: (s?: string) => typeof BSON.Decimal128.prototype;
    NumberInt: (v?: string) => typeof BSON.Int32.prototype;
    NumberLong: (s?: string | number) => typeof BSON.Long.prototype;
    ISODate: (input?: string) => Date;
    BinData: (subtype: number, b64string: string) => BinaryType;
    HexData: (subtype: number, hexstr: string) => BinaryType;
    UUID: (hexstr?: string) => BinaryType;
    MD5: (hexstr: string) => BinaryType;
    Decimal128: typeof BSON.Decimal128;
    BSONSymbol: typeof BSON.BSONSymbol;
    Int32: typeof BSON.Int32;
    Long: LongWithoutAccidentallyExposedMethods;
    Binary: typeof BSON.Binary;
    Double: typeof BSON.Double;
    EJSON: typeof BSON.EJSON;
    BSONRegExp: typeof BSON.BSONRegExp;
}
type WithHelp<T> = {
    [prop in keyof T]: T[prop] & {
        help?: () => Help;
    };
};
export type ShellBson = WithHelp<ShellBsonBase>;
export default function constructShellBson(bson: typeof BSON, printWarning: (msg: string) => void): ShellBson;
export {};
